maphash
#######

.. image:: https://img.shields.io/pypi/v/maphash?color=%2334D058&label=pypi%20package
   :target: https://pypi.org/project/maphash/

Python library for hashing lists, dicts and other JSON serializeable data structures.

.. image:: https://asciinema.org/a/5L806jTbVjlpOdy8PWplAg9MC.svg
   :target: https://asciinema.org/a/5L806jTbVjlpOdy8PWplAg9MC

Coding Conventions
==================

Python code is automatically formatted by `black`_.

Docstrings follow the `Google docstring conventions`_.

.. _`black`: https://github.com/psf/black
.. _Google docstring conventions: https://sphinxcontrib-napoleon.readthedocs.io/en/latest/example_google.html
